TopicTree

Struct TopicTree 

pub struct TopicTree { /* private fields */ }
The TopicTree is a tree structure containing all the routing information for the subscribers Subscriptions are added or removed from this structure and all clients that are subscribed to a topic can be queried from here

Implementations

Source

impl TopicTree

pub fn get_subscriptions(&self, publish_topic: &TopicName) -> Vec<Subscriber>

pub fn add_subscription( &mut self, topic_filter: TopicFilter, client_id: ClientId, qos: QoS, )

pub fn remove_subscription( &mut self, topic_filter: TopicFilter, client_id: ClientId, )